#include <ansi_c.h>
#include <utility.h>
/*=========================================================================*/
/* Cytec Main Frame RS232 LabWindows/CVI Driver Module                      */
/*=========================================================================*/

#include <rs232.h>
#include <formatio.h>
#include "CYRS232.h"

/*= Cytec Main Frame Control Module ==============================================*/
/* LabWindows Instrument Driver                                            */
/* Original Release: Dec 15, 1998                                          */
/* By: R. Singh                                                             */
/* Originally written in C                                                 */
/* Modification History: None                                              */
/*=========================================================================*/

/*= STATIC VARIABLES ======================================================*/
/* port contains the number of the port opened for the instrument module.  */
/* cmd is a buffer for RS-232 I/O strings.                                 */
/* rscnt contains the number of bytes transferred during a read or write.  */
/* CyIf3_err: the error variable for the instrument module                */
/*=========================================================================*/
//static int port;
static char cmd[26];
static int rscnt;
static int CyIf11_err;

/*= UTILITY ROUTINES ======================================================*/
int CyIf11_invalid_short_range (short val, short min, short max, int err_code);
int CyIf11_invalid_integer_range (int val, int min, int max, int err_code);
int CyIf11_invalid_longint_range (long val, long min, long max, int err_code);
int CyIf11_invalid_real_range (double val, double min, double max, int err_code);
int CyIf11_read_data (char *buf, int cnt, int term);
int CyIf11_write_data (char *buf, int cnt);
int CyIf11_device_closed (void);
void CyIf11_setup_arrays (void);

int main()
{
	CYRS232Initialize(12,9600);
	
}

/*=========================================================================*/
/* This function opens a com port for the instrument module, queries for   */
/* ID, and initializes the instrument to a known state.                    */
/*=========================================================================*/
int CYRS232Initialize(int com_port, int baud_rate)
{
	char s[40];

    if (CyIf11_invalid_integer_range (baud_rate, 110, 19200, -2) != 0)
        return -14;
    

    CyIf11_err = OpenComConfig (com_port, "", baud_rate, 0, 8, 1, 512, 512);
    if (CyIf11_err<0) {
        return CyIf11_err;
    }
    CyIf11_err = SetComTime (com_port, 1.0);
    if (CyIf11_err<0) {
        return CyIf11_err;
    }


/*
    Set port to the number of the port just opened.
*/

    RS232port = com_port;

/* Initialize communication, Answerback ON, Verbose, Echo OFF */
	Fmt (s, "A1,73;V0,73;E0,73\r");
	CyIf11_err = (ComWrt (RS232port, s, StringLength(s)));
	if (CyIf11_err<0)  {
		return CyIf11_err;
	}
	Delay(.1);
	
	CyIf11_err = ComRdTerm(RS232port, s, 40, '\r');
	if (CyIf11_err<0) {
		return CyIf11_err;
	}
	Delay (1.0);

	FlushInQ (com_port);
	FlushOutQ (com_port);

    return CyIf11_err;
}

/*=========================================================================*/
int CyIf11_read (char *buf)
{
	return(CyIf11_read_data (buf, 40, '\r'));
    
}

int CyIf11_write (char *buf)
{
	return (CyIf11_write_data (buf, StringLength(buf)));

}


/*=========================================================================*/
/* This function closes the port for the instrument module and sets the    */
/* port to zero.                                                           */
/*=========================================================================*/
int CyIf11_close (void)
{
/*  Check for device closed */

    if (CyIf11_device_closed())
        return CyIf11_err;

/*
    Close the com port.  If error, set CyIf3_err = rs232err+300.
*/

    CloseCom(RS232port);
    if (rs232err != 0) {
        CyIf11_err = rs232err+300;
        return CyIf11_err;
    }

    RS232port = 0;
    return CyIf11_err;
}

/* = UTILITY ROUTINES =====================================================*/

/*=========================================================================*/
/* Function: Invalid Short Range                                           */
/* Purpose:  This function checks a short to see if it lies between a      */
/*           minimum and maximum value.  If the value is out of range, set */
/*           the global error variable to the value err_code.  If the      */
/*           value is OK, error = 0.                                       */
/*=========================================================================*/
int CyIf11_invalid_short_range (short val, short min, short max, int err_code)
{
  if ((val < min) || (val > max)) {
    CyIf11_err = err_code;
    return -1;
  }
  return 0;
}
/*=========================================================================*/
/* Function: Invalid Integer Range                                         */
/* Purpose:  This function checks an integer to see if it lies between a   */
/*           minimum and maximum value.  If the value is out of range, set */
/*           the global error variable to the value err_code.  If the      */
/*           value is OK, error = 0.                                       */
/*=========================================================================*/
int CyIf11_invalid_integer_range (int val, int min, int max, int err_code)
{
  if ((val < min) || (val > max)) {
    CyIf11_err = err_code;
    return -1;
  }
  return 0;
}
/*=========================================================================*/
/* Function: Invalid Long Integer Range                                    */
/* Purpose:  This function checks a long integer to see if it lies between */
/*           a minimum and maximum value.  If the value is out of range,   */
/*           set the global error variable to the value err_code.  If the  */
/*           value is OK, error = 0.  The return value is equal to the     */
/*           global error value.                                           */
/*=========================================================================*/
int CyIf11_invalid_longint_range (long val, long min, long max, int err_code)
{
    if (val < min || val > max) {
        CyIf11_err = err_code;
        return -1;
    }
    return 0;
}
/*=========================================================================*/
/* Function: Invalid Real Range                                            */
/* Purpose:  This function checks a real number to see if it lies between  */
/*           a minimum and maximum value.  If the value is out of range,   */
/*           set the global error variable to the value err_code.  If the  */
/*           value is OK, error = 0.                                       */
/*=========================================================================*/
int CyIf11_invalid_real_range (double val, double min, double max, int err_code)
{
  if ((val < min) || (val > max)) {
    CyIf11_err = err_code;
    return -1;
  }
  return 0;
}
/*=========================================================================*/
/* Function: Device Closed                                                 */
/* Purpose:  This function checks to see if the module has been            */
/*           initialized.  If the device has not been opened, a 1 is       */
/*           returned, 0 otherwise.                                        */
/*=========================================================================*/
int CyIf11_device_closed (void)
{
    if (RS232port == 0)  {
        CyIf11_err = 232;
        return -1;
    }
    return 0;
}

/*=========================================================================*/
/* Function: Read Data                                                     */
/* Purpose:  This function reads a buffer of data from the instrument. The */
/*           return value is equal to the global error variable.           */
/*=========================================================================*/
int CyIf11_read_data (char *buf, int cnt, int term)
{
    rscnt = ComRdTerm(RS232port, buf, cnt, term);
    	FlushInQ (RS232port);

    return rscnt;
}

/*=========================================================================*/
/* Function: Write Data                                                    */
/* Purpose:  This function writes a buffer of data to the instrument. The  */
/*           return value is equal to the global error variable.           */
/*=========================================================================*/
int CyIf11_write_data (char *buf, int cnt)
{
    rscnt = ComWrt (RS232port, buf, cnt);
   
    return rscnt;
}

/*==========================================================================*/
/* This function is called by the init routine to initialize global arrays  */
/* This routine should be modified for each instrument to include           */
/* instrument-dependent commmand arrays.                                    */
/*==========================================================================*/
void CyIf11_setup_arrays (void)
{
}
/*= THE END ===============================================================*/
